Exception

Struct Exception 

pub struct Exception<'a, P> { /* private fields */ }
Exception Directory.

For more information see the module-level documentation.

Implementations

Source

impl<'a, P: Pe<'a>> Exception<'a, P>

pub fn pe(&self) -> P

Gets the PE instance.

pub fn image(&self) -> &'a [RUNTIME_FUNCTION]

Returns the functions slice.

pub fn check_sorted(&self) -> bool

Checks if the function table is sorted.

The PE specification says that the list of runtime functions should be sorted to allow binary search. This function checks if the runtime functions are actually sorted, if not then lookups may fail unexpectedly.

pub fn functions( &self, ) -> Map<Iter<'a, RUNTIME_FUNCTION>, impl Clone + FnMut(&'a RUNTIME_FUNCTION) -> Function<'a, P>>

Gets an iterator over the function records.

pub fn index_of(&self, pc: Rva) -> Result<usize, usize>

Finds the index of the function for the given program counter.

pub fn lookup_function_entry(&self, pc: Rva) -> Option<Function<'a, P>>

Finds the function for the given ‘program counter’ address.

The function records are sorted by their address allowing binary search for the record.